@@ -29,6 +29,21 @@ class StringChain(object):
         self.len += len(s)
         #assert self._assert_invariants()
 
+    def appendleft(self, s):
+        """ Add s to the beginning of the chain. """
+        #assert self._assert_invariants()
+        if not s:
+            return
+
+        # First trim off any ignored bytes.
+        if self.ignored:
+            self.d[0] = self.d[0][self.ignored:]
+            self.ignored = 0
+
+        self.d.appendleft(s)
+        self.len += len(s)
+        #assert self._assert_invariants()
+
     def __str__(self):
         """ Return the entire contents of this chain as a single
         string. (Obviously this requires copying all of the bytes, so don't do
