@@ -159,3 +159,27 @@ class T(unittest.TestCase):
         assert str(c2.copy()) == "ab", (str(c2.copy()),)
         c2.append("f")
         self.failUnlessEqual(str(c2.copy()), "abf")
+
+    def test_appendleft(self):
+        c1 = BufClass()
+        c1.append("abcd")
+        c1.appendleft("ef")
+        self.failUnlessEqual(str(c1.copy()), "efabcd")
+        s = c1.popleft(1)
+        self.failUnlessEqual(s, "e")
+        s = c1.popleft(2)
+        self.failUnlessEqual(s, "fa")
+        s = c1.popleft(3)
+        self.failUnlessEqual(s, "bcd")
+
+        c1 = BufClass()
+        c1.append("abcd")
+        c1.popleft(1)
+        c1.appendleft("ef")
+        self.failUnlessEqual(str(c1.copy()), "efbcd")
+        s = c1.popleft(1)
+        self.failUnlessEqual(s, "e")
+        s = c1.popleft(2)
+        self.failUnlessEqual(s, "fb")
+        s = c1.popleft(3)
+        self.failUnlessEqual(s, "cd")
